TrackedField

Struct TrackedField 

pub struct TrackedField<'s, T, F> { /* private fields */ }
A tracked field in a tracked struct which sets a flag when the value is changed.

Implementations

Source

impl<'s, T, F> TrackedField<'s, T, F>
where F: Flags + Clone,

pub fn new(flag: F, track_flags: &'s mut F, value: &'s mut T) -> Self

Create a new tracked field

pub fn force_set(&mut self, value: T)

Forces an update, regardless of whether the value has changed.

pub fn update(&mut self, f: impl FnOnce(&mut T) -> bool) -> bool

Updates the value via a closure It should return true if the value has changed.

pub fn force_update(&mut self, f: impl FnOnce(&mut T))

Forces an update via a closure

pub fn update_opt(&mut self, f: impl FnOnce(&mut T) -> Option<T>) -> bool

Update with an option closure, only sets the flag is Some is returned useful for checked updates Returns true if the value was updated

Source

impl<T, F> TrackedField<'_, T, F>
where T: PartialEq, F: Flags + Clone,

pub fn set(&mut self, value: T)

Set the value to the new one, but only set the flag whether the value changes