pub struct TrackedField<'s, T, F> { /* private fields */ }Expand description
A tracked field in a tracked struct which sets a flag when the value is changed.
Implementations
Sourceimpl<'s, T, F> TrackedField<'s, T, F>
impl<'s, T, F> TrackedField<'s, T, F>
Sourcepub fn new(flag: F, track_flags: &'s mut F, value: &'s mut T) -> Self
pub fn new(flag: F, track_flags: &'s mut F, value: &'s mut T) -> Self
Create a new tracked field
Sourcepub fn force_set(&mut self, value: T)
pub fn force_set(&mut self, value: T)
Forces an update, regardless of whether the value has changed.
Sourcepub fn update(&mut self, f: impl FnOnce(&mut T) -> bool) -> bool
pub fn update(&mut self, f: impl FnOnce(&mut T) -> bool) -> bool
Updates the value via a closure It should return true if the value has changed.
Sourcepub fn force_update(&mut self, f: impl FnOnce(&mut T))
pub fn force_update(&mut self, f: impl FnOnce(&mut T))
Forces an update via a closure